@@ -4,29 +4,19 @@
  */
 
 #pragma once
-#include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/ec2/EC2_EXPORTS.h>
 
-namespace Aws
-{
-namespace EC2
-{
-namespace Model
-{
-  enum class ClientVpnAuthenticationType
-  {
-    NOT_SET,
-    certificate_authentication,
-    directory_service_authentication,
-    federated_authentication
-  };
+namespace Aws {
+namespace EC2 {
+namespace Model {
+enum class ClientVpnAuthenticationType { NOT_SET, certificate_authentication, directory_service_authentication, federated_authentication };
 
-namespace ClientVpnAuthenticationTypeMapper
-{
+namespace ClientVpnAuthenticationTypeMapper {
 AWS_EC2_API ClientVpnAuthenticationType GetClientVpnAuthenticationTypeForName(const Aws::String& name);
 
 AWS_EC2_API Aws::String GetNameForClientVpnAuthenticationType(ClientVpnAuthenticationType value);
-} // namespace ClientVpnAuthenticationTypeMapper
-} // namespace Model
-} // namespace EC2
-} // namespace Aws
+}  // namespace ClientVpnAuthenticationTypeMapper
+}  // namespace Model
+}  // namespace EC2
+}  // namespace Aws
