@@ -4,29 +4,19 @@
  */
 
 #pragma once
-#include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/ec2/EC2_EXPORTS.h>
 
-namespace Aws
-{
-namespace EC2
-{
-namespace Model
-{
-  enum class DefaultInstanceMetadataTagsState
-  {
-    NOT_SET,
-    disabled,
-    enabled,
-    no_preference
-  };
+namespace Aws {
+namespace EC2 {
+namespace Model {
+enum class DefaultInstanceMetadataTagsState { NOT_SET, disabled, enabled, no_preference };
 
-namespace DefaultInstanceMetadataTagsStateMapper
-{
+namespace DefaultInstanceMetadataTagsStateMapper {
 AWS_EC2_API DefaultInstanceMetadataTagsState GetDefaultInstanceMetadataTagsStateForName(const Aws::String& name);
 
 AWS_EC2_API Aws::String GetNameForDefaultInstanceMetadataTagsState(DefaultInstanceMetadataTagsState value);
-} // namespace DefaultInstanceMetadataTagsStateMapper
-} // namespace Model
-} // namespace EC2
-} // namespace Aws
+}  // namespace DefaultInstanceMetadataTagsStateMapper
+}  // namespace Model
+}  // namespace EC2
+}  // namespace Aws
