@@ -4,28 +4,19 @@
  */
 
 #pragma once
-#include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/ec2/EC2_EXPORTS.h>
 
-namespace Aws
-{
-namespace EC2
-{
-namespace Model
-{
-  enum class EkPubKeyFormat
-  {
-    NOT_SET,
-    der,
-    tpmt
-  };
+namespace Aws {
+namespace EC2 {
+namespace Model {
+enum class EkPubKeyFormat { NOT_SET, der, tpmt };
 
-namespace EkPubKeyFormatMapper
-{
+namespace EkPubKeyFormatMapper {
 AWS_EC2_API EkPubKeyFormat GetEkPubKeyFormatForName(const Aws::String& name);
 
 AWS_EC2_API Aws::String GetNameForEkPubKeyFormat(EkPubKeyFormat value);
-} // namespace EkPubKeyFormatMapper
-} // namespace Model
-} // namespace EC2
-} // namespace Aws
+}  // namespace EkPubKeyFormatMapper
+}  // namespace Model
+}  // namespace EC2
+}  // namespace Aws
