@@ -4,30 +4,19 @@
  */
 
 #pragma once
-#include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/ec2/EC2_EXPORTS.h>
 
-namespace Aws
-{
-namespace EC2
-{
-namespace Model
-{
-  enum class ExportTaskState
-  {
-    NOT_SET,
-    active,
-    cancelling,
-    cancelled,
-    completed
-  };
+namespace Aws {
+namespace EC2 {
+namespace Model {
+enum class ExportTaskState { NOT_SET, active, cancelling, cancelled, completed };
 
-namespace ExportTaskStateMapper
-{
+namespace ExportTaskStateMapper {
 AWS_EC2_API ExportTaskState GetExportTaskStateForName(const Aws::String& name);
 
 AWS_EC2_API Aws::String GetNameForExportTaskState(ExportTaskState value);
-} // namespace ExportTaskStateMapper
-} // namespace Model
-} // namespace EC2
-} // namespace Aws
+}  // namespace ExportTaskStateMapper
+}  // namespace Model
+}  // namespace EC2
+}  // namespace Aws
