@@ -4,27 +4,19 @@
  */
 
 #pragma once
-#include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/ec2/EC2_EXPORTS.h>
 
-namespace Aws
-{
-namespace EC2
-{
-namespace Model
-{
-  enum class FleetCapacityReservationTenancy
-  {
-    NOT_SET,
-    default_
-  };
+namespace Aws {
+namespace EC2 {
+namespace Model {
+enum class FleetCapacityReservationTenancy { NOT_SET, default_ };
 
-namespace FleetCapacityReservationTenancyMapper
-{
+namespace FleetCapacityReservationTenancyMapper {
 AWS_EC2_API FleetCapacityReservationTenancy GetFleetCapacityReservationTenancyForName(const Aws::String& name);
 
 AWS_EC2_API Aws::String GetNameForFleetCapacityReservationTenancy(FleetCapacityReservationTenancy value);
-} // namespace FleetCapacityReservationTenancyMapper
-} // namespace Model
-} // namespace EC2
-} // namespace Aws
+}  // namespace FleetCapacityReservationTenancyMapper
+}  // namespace Model
+}  // namespace EC2
+}  // namespace Aws
