@@ -4,29 +4,19 @@
  */
 
 #pragma once
-#include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/ec2/EC2_EXPORTS.h>
 
-namespace Aws
-{
-namespace EC2
-{
-namespace Model
-{
-  enum class ImageTypeValues
-  {
-    NOT_SET,
-    machine,
-    kernel,
-    ramdisk
-  };
+namespace Aws {
+namespace EC2 {
+namespace Model {
+enum class ImageTypeValues { NOT_SET, machine, kernel, ramdisk };
 
-namespace ImageTypeValuesMapper
-{
+namespace ImageTypeValuesMapper {
 AWS_EC2_API ImageTypeValues GetImageTypeValuesForName(const Aws::String& name);
 
 AWS_EC2_API Aws::String GetNameForImageTypeValues(ImageTypeValues value);
-} // namespace ImageTypeValuesMapper
-} // namespace Model
-} // namespace EC2
-} // namespace Aws
+}  // namespace ImageTypeValuesMapper
+}  // namespace Model
+}  // namespace EC2
+}  // namespace Aws
