@@ -4,28 +4,19 @@
  */
 
 #pragma once
-#include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/ec2/EC2_EXPORTS.h>
 
-namespace Aws
-{
-namespace EC2
-{
-namespace Model
-{
-  enum class InstanceStorageEncryptionSupport
-  {
-    NOT_SET,
-    unsupported,
-    required
-  };
+namespace Aws {
+namespace EC2 {
+namespace Model {
+enum class InstanceStorageEncryptionSupport { NOT_SET, unsupported, required };
 
-namespace InstanceStorageEncryptionSupportMapper
-{
+namespace InstanceStorageEncryptionSupportMapper {
 AWS_EC2_API InstanceStorageEncryptionSupport GetInstanceStorageEncryptionSupportForName(const Aws::String& name);
 
 AWS_EC2_API Aws::String GetNameForInstanceStorageEncryptionSupport(InstanceStorageEncryptionSupport value);
-} // namespace InstanceStorageEncryptionSupportMapper
-} // namespace Model
-} // namespace EC2
-} // namespace Aws
+}  // namespace InstanceStorageEncryptionSupportMapper
+}  // namespace Model
+}  // namespace EC2
+}  // namespace Aws
