@@ -4,28 +4,19 @@
  */
 
 #pragma once
-#include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/ec2/EC2_EXPORTS.h>
 
-namespace Aws
-{
-namespace EC2
-{
-namespace Model
-{
-  enum class ManagedBy
-  {
-    NOT_SET,
-    account,
-    declarative_policy
-  };
+namespace Aws {
+namespace EC2 {
+namespace Model {
+enum class ManagedBy { NOT_SET, account, declarative_policy };
 
-namespace ManagedByMapper
-{
+namespace ManagedByMapper {
 AWS_EC2_API ManagedBy GetManagedByForName(const Aws::String& name);
 
 AWS_EC2_API Aws::String GetNameForManagedBy(ManagedBy value);
-} // namespace ManagedByMapper
-} // namespace Model
-} // namespace EC2
-} // namespace Aws
+}  // namespace ManagedByMapper
+}  // namespace Model
+}  // namespace EC2
+}  // namespace Aws
